@@ -7,5 +7,6 @@ from . import views
 
 
 urlpatterns = patterns('',
-    url(r"^$", views.generate_identity),
-    url(r"^(?P<identity>\d+)/$", views.message_tester))
+    url(r"^(?P<backend_name>[\w-]+)/$", views.generate_identity),
+    url(r"^(?P<backend_name>[\w-]+)/(?P<identity>\d+)/$", views.message_tester)
+)
