@@ -5,6 +5,6 @@ from django.conf.urls.defaults import *
 from . import views
 
 urlpatterns = patterns('',
-    url(r'^logger/$',
+    url(r'^$',
         views.message_log,
         name="message_log"))
